@@ -28,6 +28,7 @@ from stackalytics.processor import rcs
 from stackalytics.processor import user_processor
 from stackalytics.processor import utils
 
+CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 GITHUB_URI_PREFIX = r'^github:\/\/'
@@ -50,7 +51,7 @@ def _check_default_data_change(runtime_storage_inst, default_data):
 
 def _retrieve_project_list_from_sources(project_sources):
     for project_source in project_sources:
-        uri = project_source.get('uri') or cfg.CONF.review_uri
+        uri = project_source.get('uri') or CONF.review_uri
         repo_iterator = []
         if re.search(rcs.GERRIT_URI_PREFIX, uri):
             repo_iterator = _retrieve_project_list_from_gerrit(project_source)
@@ -66,25 +67,24 @@ def _retrieve_project_list_from_sources(project_sources):
 def _retrieve_project_list_from_gerrit(project_source):
     LOG.info('Retrieving project list from Gerrit')
     try:
-        uri = project_source.get('uri') or cfg.CONF.review_uri
+        uri = project_source.get('uri') or CONF.review_uri
         gerrit_inst = rcs.Gerrit(uri)
         key_filename = (project_source.get('ssh_key_filename') or
-                        cfg.CONF.ssh_key_filename)
-        username = project_source.get('ssh_username') or cfg.CONF.ssh_username
+                        CONF.ssh_key_filename)
+        username = project_source.get('ssh_username') or CONF.ssh_username
         gerrit_inst.setup(key_filename=key_filename, username=username)
 
         project_list = gerrit_inst.get_project_list()
         gerrit_inst.close()
-    except Exception as e:
-        LOG.exception(e)
-        LOG.warn('Fail to retrieve list of projects. Keep it unmodified')
-        return
+    except rcs.RcsException:
+        LOG.error('Failed to retrieve list of projects')
+        raise
 
     organization = project_source['organization']
     LOG.debug('Get list of projects for organization %s', organization)
     git_repos = [f for f in project_list if f.startswith(organization + "/")]
 
-    git_base_uri = project_source.get('git_base_uri') or cfg.CONF.git_base_uri
+    git_base_uri = project_source.get('git_base_uri') or CONF.git_base_uri
 
     for repo in git_repos:
         (org, name) = repo.split('/')
@@ -95,7 +95,8 @@ def _retrieve_project_list_from_gerrit(project_source):
             'module': name,
             'organization': org,
             'uri': repo_uri,
-            'releases': []
+            'releases': [],
+            'has_gerrit': True,
         }
 
 
@@ -108,9 +109,9 @@ def _retrieve_project_list_from_github(project_source):
     try:
         github_repos = github.get_organization(organization).get_repos()
     except Exception as e:
-        LOG.exception(e)
-        LOG.warn('Fail to retrieve list of projects. Keep it unmodified')
-        return
+        LOG.error('Failed to retrieve list of projects from GitHub: %s',
+                  e, exc_info=True)
+        raise
 
     for repo in github_repos:
         yield {
@@ -127,15 +128,24 @@ def _create_module_groups_for_project_sources(project_sources, repos):
     for repo in repos:
         organizations[repo['organization']].append(repo['module'])
 
-    ps_organizations = dict([(ps.get('organization'),
-                              ps.get('module_group_name') or
-                              ps.get('organization'))
-                             for ps in project_sources])
+    # organization -> (module_group_id, module_group_name)
+    ps_organizations = dict(
+        [(ps.get('organization'),
+          (ps.get('module_group_id') or ps.get('organization'),
+           ps.get('module_group_name') or ps.get('organization')))
+         for ps in project_sources])
 
     module_groups = []
     for ogn, modules in six.iteritems(organizations):
+        module_group_id = ogn
+        module_group_name = ogn
+
+        if ogn in ps_organizations:
+            module_group_id = ps_organizations[ogn][0]
+            module_group_name = ps_organizations[ogn][1]
+
         module_groups.append(utils.make_module_group(
-            ogn, name=ps_organizations.get(ogn, ogn), modules=modules,
+            module_group_id, name=module_group_name, modules=modules,
             tag='organization'))
 
     return module_groups
@@ -148,7 +158,16 @@ def _update_project_list(default_data):
     repos = _retrieve_project_list_from_sources(
         default_data['project_sources'])
     if repos:
-        default_data['repos'] += [r for r in repos
+        # update pre-configured
+        repos_dict = dict((r['uri'], r) for r in repos)
+        for r in default_data['repos']:
+            if r['uri'] in repos_dict:
+                for k, v in repos_dict[r['uri']].items():
+                    if k not in r:
+                        r[k] = v
+
+        # update default data
+        default_data['repos'] += [r for r in repos_dict.values()
                                   if r['uri'] not in configured_repos]
 
     default_data['module_groups'] += _create_module_groups_for_project_sources(
@@ -160,7 +179,7 @@ def _update_with_driverlog_data(default_data, driverlog_data_uri):
     driverlog_data = utils.read_json_from_uri(driverlog_data_uri)
 
     if not driverlog_data:
-        LOG.warn('DriverLog data is not available')
+        LOG.warning('DriverLog data is not available')
         return
 
     module_cis = collections.defaultdict(list)
