@@ -27,23 +27,24 @@ from oslo_log import log as logging
 import requests
 import requests_file
 import six
+import yaml
 
 
+CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
 def init_config_and_logging(opts):
-    conf = cfg.CONF
-    conf.register_cli_opts(opts)
-    conf.register_opts(opts)
-    logging.register_options(conf)
+    CONF.register_cli_opts(opts)
+    CONF.register_opts(opts)
+    logging.register_options(CONF)
     logging.set_defaults()
 
-    conf(project='stackalytics')
+    CONF(project='stackalytics')
 
-    logging.setup(conf, 'stackalytics')
+    logging.setup(CONF, 'stackalytics')
     LOG.info('Logging enabled')
-    conf.log_opt_values(LOG, logging.DEBUG)
+    CONF.log_opt_values(LOG, logging.DEBUG)
 
 
 def date_to_timestamp(d):
@@ -121,7 +122,9 @@ def _session_request(session, uri, method):
     session.mount('file://', requests_file.FileAdapter())
     user_agent = random.choice(user_agents)
 
-    return session.request(method, uri, headers={'User-Agent': user_agent})
+    headers = {'User-Agent': user_agent, 'Accept': 'application/json'}
+    return session.request(method, uri, headers=headers,
+                           timeout=CONF.read_timeout)
 
 
 def do_request(uri, method='get', session=None):
@@ -136,16 +139,24 @@ def read_uri(uri, session=None):
     try:
         return do_request(uri, session=session).text
     except Exception as e:
-        LOG.warn('Error "%(error)s" retrieving uri %(uri)s',
-                 {'error': e, 'uri': uri})
+        LOG.warning('Error "%(error)s" retrieving uri %(uri)s',
+                    {'error': e, 'uri': uri})
 
 
 def read_json_from_uri(uri, session=None):
     try:
         return do_request(uri, session=session).json()
     except Exception as e:
-        LOG.warn('Error "%(error)s" parsing json from uri %(uri)s',
-                 {'error': e, 'uri': uri})
+        LOG.warning('Error "%(error)s" parsing json from uri %(uri)s',
+                    {'error': e, 'uri': uri})
+
+
+def read_yaml_from_uri(uri):
+    try:
+        return yaml.safe_load(read_uri(uri))
+    except Exception as e:
+        LOG.warning('Error "%(error)s" parsing yaml from uri %(uri)s',
+                    {'error': e, 'uri': uri})
 
 
 def _gzip_decompress(content):
@@ -160,16 +171,16 @@ def read_gzip_from_uri(uri):
     try:
         return _gzip_decompress(do_request(uri).content)
     except Exception as e:
-        LOG.warn('Error "%(error)s" retrieving uri %(uri)s',
-                 {'error': e, 'uri': uri})
+        LOG.warning('Error "%(error)s" retrieving uri %(uri)s',
+                    {'error': e, 'uri': uri})
 
 
 def get_uri_last_modified(uri):
     try:
         return do_request(uri, method='head').headers['last-modified']
     except Exception as e:
-        LOG.warn('Error "%(error)s" retrieving uri %(uri)s',
-                 {'error': e, 'uri': uri})
+        LOG.warning('Error "%(error)s" retrieving uri %(uri)s',
+                    {'error': e, 'uri': uri})
 
 
 def cmp_to_key(mycmp):  # ported from python 3
